==> mutual_credit-5.0.10.tar.gz: mutual_credit/modules/limits/src/Plugin/Limits/Balanced.php <==
<?php

namespace Drupal\mcapi_limits\Plugin\Limits;

use Drupal\mcapi\Entity\WalletInterface;
use Drupal\mcapi_limits\Plugin\McapiLimitsBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * No balance limits.
 *
 * @Limits(
 *   id = "balanced",
 *   label = @Translation("Balanced"),
 *   description = @Translation("Limits are the same distance from zero")
 * )
 */
class Balanced extends McapiLimitsBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    // The order seemes to matter more than the weight.
    $form['liquidity'] = [
      '#title' => $this->t('Liquidity per user'),
      '#description' => $this->t('The distance from zero a user can trade'),
      '#type' => 'worth_form',
      '#allowed_curr_ids' => [$this->currency->id()],
      '#default_value' => [
          'curr_id' => $this->currency->id(),
          'value' => $this->configuration['balanced']['liquidity']
        ],
      '#min' => 0,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getLimits(WalletInterface $wallet) {
    $conf = $this->configuration['liquidity'] ?? NULL;
    return [
      'min' => -$conf,
      'max' => $conf,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $defaults = parent::defaultConfiguration();
    $defaults['balanced'] = [
      // This is the format the worth widget expects.
      'liquidity' => 1000
    ];
    return $defaults;
  }


  function getWorthFields() {
    return ['liquidity'];
  }

}

==> mutual_credit-5.1.0.tar.gz: mutual_credit/modules/limits/src/Plugin/Limits/Balanced.php <==
<?php

namespace Drupal\mcapi_limits\Plugin\Limits;

use Drupal\mcapi\Entity\WalletInterface;
use Drupal\mcapi_limits\Plugin\McapiLimitsBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * No balance limits.
 *
 * @Limits(
 *   id = "balanced",
 *   label = @Translation("Balanced"),
 *   description = @Translation("Limits are the same distance from zero")
 * )
 */
class Balanced extends McapiLimitsBase {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    // The order seemes to matter more than the weight.
    $form['liquidity'] = [
      '#title' => $this->t('Liquidity per user'),
      '#description' => $this->t('The distance from zero a user can trade'),
      '#type' => 'worth_form',
      '#allowed_curr_ids' => [$this->currency->id()],
      '#default_value' => [
          'curr_id' => $this->currency->id(),
          'value' => $this->configuration['balanced']['liquidity']
        ],
      '#min' => 0,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function currencyLimits(WalletInterface $wallet) {
    $conf = $this->configuration['balanced']['liquidity'] ?? NULL;
    return [
      'min' => -$conf,
      'max' => $conf,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $defaults = parent::defaultConfiguration();
    $defaults['balanced'] = [
      // This is the format the worth widget expects.
      'liquidity' => 1500
    ];
    return $defaults;
  }


  function getWorthFields() {
    return ['liquidity'];
  }

}
